package cn.com.ctop.kuaishou.modules.batch.service.impl;

import cn.com.ctop.common.module.service.ISendMessageService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.common.module.utils.HttpUtils;
import cn.com.ctop.kuaishou.modules.batch.entity.JyOrderList;

import cn.com.ctop.kuaishou.modules.batch.mapper.JiaoYangFenXiaoMapper;
import cn.com.ctop.kuaishou.modules.batch.service.IJiaoYangFenXiaoService;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class JiaoYangFenXiaoServiceImpl implements IJiaoYangFenXiaoService {

    private static String url = "https://cps.kwaixiaodian.com/gateway/distribute/platform/mcn/order/list";

    @Autowired
    private JiaoYangFenXiaoMapper jiaoYangFenXiaoMapper;
    @Autowired
    private ISendMessageService sendMessageService;

    @Override
    public List<JSONObject> getCookie() {
        return jiaoYangFenXiaoMapper.getCookie();
    }

    @Override
    public void getOrderList(String cookie, Integer offset, Long orderCreateTimeStart, Long orderCreateTimeEnd) throws Exception {
        Thread.sleep(500L);
        Map<String, Object> params = new HashMap<>();
        if (!Check.isNull(orderCreateTimeStart)) {
            params.put("orderCreateTimeStart", orderCreateTimeStart);
        }
        if (!Check.isNull(orderCreateTimeEnd)) {
            params.put("orderCreateTimeEnd", orderCreateTimeEnd);
        }
      //  params.put("fundType", 1);
        params.put("limit", 200);
        params.put("offset", offset);

        Map<String, String> headers = new HashMap<>();
        headers.put("Cookie", cookie);

        String resultStr = HttpUtils.KuaiShouttpGetRequest(url, params, headers);
        JSONObject result = JSONObject.parseObject(resultStr);
        if (Check.isNull(result)) {
            log.error("骄阳分销数据返回为空");
            return;
        }
        Integer code = result.getInteger("result");
        if (code != 1) {
            log.info("骄阳分销数据返回异常：", resultStr);
            sendMessageService.sendMessage("113dee46c7df464da78c07a985e92cd1", "骄阳分销cookie失效，请及时更新。媒体返回信息：" + resultStr);
            return;
        }
        JSONObject dataJson = result.getJSONObject("data");
        if (Check.isNull(dataJson)) {
            log.error("骄阳分销数据返回为data数据为空");
            return;
        }
        JSONArray list = dataJson.getJSONArray("list");
        if (Check.isNull(list)) {
            log.error("骄阳分销数据返回为list数据为空");
            return;
        }
        log.info("骄阳分销当前数据条数:{}", list.size());
        List<JyOrderList> orders = new ArrayList<>();
        for (int i = 0; i < list.size(); i++) {
            JSONObject jsonObject = list.getJSONObject(i);
            JyOrderList order = new JyOrderList();
            order.setOid(jsonObject.getLong("oid"));
            JSONObject item = jsonObject.getJSONArray("itemList").getJSONObject(0);
            if (!Check.isNull(item)) {
                order.setItemId(item.getLong("itemId"));
                order.setItemTitle(item.getString("itemTitle"));
                order.setReservePrice(item.getLong("reservePrice"));
                order.setImageUrl(item.getString("imageUrl"));
            }
            order.setOrderStatus(jsonObject.getInteger("orderStatus"));
            order.setOrderCreateTime(jsonObject.getLong("orderCreateTime"));
            order.setSendStatus(jsonObject.getInteger("sendStatus"));
            order.setSettlementBizType(jsonObject.getInteger("settlementBizType"));
            order.setSettlementBizTypeDesc(jsonObject.getString("settlementBizTypeDesc"));
            order.setSendTime(jsonObject.getLong("sendTime"));
            order.setRecvTime(jsonObject.getLong("recvTime"));
            order.setSellerId(jsonObject.getLong("sellerId"));
            order.setPromotionId(jsonObject.getLong("promotionId"));
            order.setPromotionNickName(filterSupplement(jsonObject.getString("promotionNickName")));
            order.setClipUserId(jsonObject.getLong("clipUserId"));
            order.setClipNickName(jsonObject.getString("clipNickName"));
            order.setActivityId(jsonObject.getLong("activityId"));
            order.setOrderAmount(jsonObject.getLong("orderAmount"));
            order.setPayAmount(jsonObject.getLong("payAmount"));
            order.setRegimentalPromotionRate(jsonObject.getLong("regimentalPromotionRate"));
            order.setShareRate(jsonObject.getLong("shareRate"));
            order.setBaseAmount(jsonObject.getLong("baseAmount"));
            order.setCommissionRate(jsonObject.getLong("commissionRate"));
            order.setRegimentalPromotionAmount(jsonObject.getLong("regimentalPromotionAmount"));
            order.setTotalRegimentalSettleAmount(jsonObject.getLong("totalRegimentalSettleAmount"));
            order.setStatDate(DateUtils.tempToLongDate(jsonObject.getLong("orderCreateTime")));
            orders.add(order);
        }
        jiaoYangFenXiaoMapper.replace(orders);
        if (list.size() >= 200) {
            getOrderList(cookie, offset + 200, orderCreateTimeStart, orderCreateTimeEnd);
        }

    }


    public static String filterSupplement(String content) {
        StringBuilder sb = new StringBuilder();
        for (char ch : content.toCharArray()) {
            if (!Character.isHighSurrogate(ch) && !Character.isLowSurrogate(ch)) {
                sb.append(ch);
            }
        }
        return sb.toString();
    }

}
